@@ -13,7 +13,7 @@ our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(tidy_xml object_to_xml xml_to_object simple_to_xml xml_to_simple check_xml xml_escape);
 our %EXPORT_TAGS = (all => [@EXPORT_OK]);
 
-our $VERSION = "1.03";
+our $VERSION = "1.04";
 
 my $DEFAULT_INDENTSTRING = ' ' x 4;
 
@@ -494,7 +494,7 @@ represent its list of addresses under an arrayref, like this:
     </person>
 
 Finally, to set attributes to your elements (eg id="12") you need to replace the key with either
-a string containing attributes as well (eg: 'address id="12"'), or replace it with a reference, as the many
+a string containing attributes as well (eg: C<'address id="12"'>), or replace it with a reference, as the many
 items in the examples below:
 
     {thing => [
@@ -525,7 +525,7 @@ the "correct" one.
 Of course if the "simple structure" is a hashref, the key cannot be a reference (because hash keys are always
 strings), so if you want attributes on your elements, you either need the enclosing structure to be an
 arrayref as in the example above, to allow keys to be refs which contain the attributes, or you need to
-represent the key (=tag+attrs) as a string, like this (also in the previous example): 'item id="1"'
+represent the key (=tag+attrs) as a string, like this (also in the previous example): C<'item id="1"'>
 
 This concludes the mini-tutorial of the simple_to_xml function.
 
@@ -649,11 +649,17 @@ sub _hashref_to_xml {
 
 =head2 xml_to_simple($raw_xml)
 
-Produces a very simple hash object from the raw XML string provided. An example hash object created thusly is this: S<C<< { thing => { name => 'John', location => { city => 'New York', country => 'U.S.A.' } } } >>>
+Produces a very simple hash object from the raw XML string provided. An example hash object created thusly is this:
+S<C<< { thing => { name => 'John', location => { city => 'New York', country => 'U.S.A.' } } } >>>
 
-Since the object created is a hashref, duplicate keys will be discarded. WARNING: This function only works on very simple XML strings, i.e. children of an element may not consist of both text and elements (child elements will be discarded in that case)
+B<WARNING:> This function only works on very simple XML strings, i.e. children of an element may not consist of both
+text and elements (child elements will be discarded in that case). Also attributes in tags are ignored.
 
-All strings contained in the output simple structure, will always contain characters rather than octets/bytes, regardless of the C<bytes> optional flag.
+Since the object created is a hashref (unless used with the C<arrayref> optional flag), duplicate keys will be
+discarded.
+
+All strings contained in the output simple structure will always contain characters rather than octets/bytes,
+regardless of the C<bytes> optional flag.
 
 Optional flags: C<internal>, C<strip>, C<file>, C<strip_ns>, C<arrayref>, C<bytes>
 
